@@ -145,7 +145,14 @@ impl From<&Path> for IgnoreFilesFromOriginArgs {
 ///
 /// This function panics if the `args` are not correctly-formed; this can be checked beforehand
 /// without panicking with [`IgnoreFilesFromOriginArgs::check()`].
-#[allow(clippy::future_not_send)]
+#[expect(
+	clippy::future_not_send,
+	reason = "gix_config internals, if this changes: update the doc"
+)]
+#[allow(
+	clippy::too_many_lines,
+	reason = "it's just the discover_file calls that explode the line count"
+)]
 pub async fn from_origin(
 	args: impl Into<IgnoreFilesFromOriginArgs>,
 ) -> (Vec<IgnoreFile>, Vec<Error>) {
@@ -175,7 +182,7 @@ pub async fn from_origin(
 			)),
 			Some(Err(err)) => errors.push(Error::new(ErrorKind::Other, err)),
 			Some(Ok(config)) => {
-				let config_excludes = config.value::<GitPath<'_>>("core", None, "excludesFile");
+				let config_excludes = config.value::<GitPath<'_>>("core.excludesFile");
 				if let Ok(excludes) = config_excludes {
 					match excludes.interpolate(InterpolateContext {
 						home_dir: env::var("HOME").ok().map(PathBuf::from).as_deref(),
@@ -314,7 +321,11 @@ pub async fn from_origin(
 /// ## Async
 ///
 /// This future is not `Send` due to [`gix_config`] internals.
-#[allow(clippy::future_not_send)]
+#[expect(
+	clippy::future_not_send,
+	reason = "gix_config internals, if this changes: update the doc"
+)]
+#[allow(clippy::too_many_lines, reason = "clearer than broken up needlessly")]
 pub async fn from_environment(appname: Option<&str>) -> (Vec<IgnoreFile>, Vec<Error>) {
 	let mut files = Vec::new();
 	let mut errors = Vec::new();
@@ -329,7 +340,7 @@ pub async fn from_environment(appname: Option<&str>) -> (Vec<IgnoreFile>, Vec<Er
 		Err(err) => errors.push(Error::new(ErrorKind::Other, err)),
 		Ok(Err(err)) => errors.push(Error::new(ErrorKind::Other, err)),
 		Ok(Ok(config)) => {
-			let config_excludes = config.value::<GitPath<'_>>("core", None, "excludesFile");
+			let config_excludes = config.value::<GitPath<'_>>("core.excludesFile");
 			if let Ok(excludes) = config_excludes {
 				match excludes.interpolate(InterpolateContext {
 					home_dir: env::var("HOME").ok().map(PathBuf::from).as_deref(),
